# Scaling and Display Levels

In Display levels and colors user sets mapping between image pixel intensities and displayed colors on the 2D plot.

- scaling: `sqrt`, `linear` or `log` – basic intensity scale for 2D images
  applied to`Image Statistics/1D plot` or not – depending on `Configuration`
- Levels: maximum and minimum intensity displayed. It can be automatic or set by user
- Auto levels %: switch to automatic levels settings. You can provide the levels as a cut factor in % of the highest pick.
- Bin edges: bin edges algorithm for finding histogram levels
- Step: step parameter for the bin edges algorithm for finding histogram levels
- Histogram: set intensity levels and color gradients on histogram plot
- Color gradients: 12 various basic settings with possibility to adjust with ticks

By clicking the right-mouse-button on the color gradient bar you can save or remove your current customize color gradient into the local configuration (only in the expert mode).

For multi-channel images user can select a separate color channel, a sum or mean of all color channels or an RGB view.